@@ -1,6 +1,7 @@
-from datetime import datetime
 from collections import defaultdict
 from django.db.models import Manager
+from django.db.models.query import QuerySet
+from django.utils import timezone
 from alert.utils import ALERT_TYPES, ALERT_BACKENDS
 
 
@@ -17,11 +18,11 @@ class PendingAlertManager(AlertManager):
     
     def get_query_set(self, *args, **kwargs):
         qs = super(PendingAlertManager, self).get_query_set(*args, **kwargs)
-        return qs.filter(when__lte=datetime.now(), is_sent=False)
-    
-    
-    
-    
+        return qs.filter(when__lte=timezone.now(), is_sent=False)
+
+
+
+
 class AlertPrefsManager(Manager):
     
     def get_user_prefs(self, user):
@@ -52,7 +53,13 @@ class AlertPrefsManager(Manager):
         
         if not users: return ()
         
-        alert_prefs = self.get_query_set().filter(alert_type=notice_type.id).filter(user__in=users)
+        # this optimization really shouldn't be necessary, but it makes a huge difference on mysql
+        if isinstance(users, QuerySet):
+          user_ids = list(users.values_list("id", flat=True))
+        else:
+          user_ids = [u.id for u in users]
+        
+        alert_prefs = self.get_query_set().filter(alert_type=notice_type.id).filter(user__in=user_ids)
         
         prefs = {}
         for pref in alert_prefs:
